/***************************************************************************
 *   Copyright (C) 2005 by Ken Werner                                      *
 *   ken.werner@web.de                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef CPUDATA_H
#define CPUDATA_H

#include "sources/source.h"
#include <qstring.h>
#include <qstringlist.h> 
#include <vector>

/**
 * @author Ken Werner
 */
class CPUData{
public:
	CPUData();
	virtual ~CPUData();

	/**
	 * searches for thermal sources such as /proc/acpi/thermal/THM0/temperature
	 * and adds them to mThermalSources
	 */
	void findThermalSources();

	/**
	 * searches for frequency sources such as /sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq
	 * and adds them to mFrequencySources
	 */
	void findFrequencySources();

	/**
	 * Returns all thermal sources
	 */
	const std::vector<Source*>& getThermalSources();

	/**
	 * Returns the Names of all ThermalSources
	 */
	QStringList getThermalSourceList();

	/**
	 * Returns all frequency sources
	 */
	const std::vector<Source*>& getFrequencySources();

	/**
	 * Returns the Names of all FrequencySources
	 */
	QStringList getFrequencySourceList();

private:
	/**
	 * stores the thermal sources
	 */
	std::vector<Source*> mThermalSources;

	/**
	 * stores the frequency sources
	 */
	std::vector<Source*> mFrequencySources;
};
#endif
